## 0.2.0 - 2022-06-20

### Added

- [#475](https://github.com/edgarrmondragon/citric/issues/475) Implement `update_response` in client

### Fixed

- [#477](https://github.com/edgarrmondragon/citric/issues/477) Reduce number of calls to `list_questions` from `add_responses`
